@@ -1,7 +1,5 @@
 package App::Info::Lib::Iconv;
 
-# $Id: Iconv.pm 2577 2006-02-05 03:11:10Z theory $
-
 =head1 NAME
 
 App::Info::Lib::Iconv - Information about libiconv
@@ -27,7 +25,7 @@ installed on the local system. It implements all of the methods defined by
 App::Info::Lib. Methods that trigger events will trigger them only the first
 time they're called (See L<App::Info|App::Info> for documentation on handling
 events). To start over (after, say, someone has installed libiconv) construct
-a new App::Info::Lib::Iconv object to aggregate new metadata.
+a new App::Info::Lib::Iconv object to aggregate new meta data.
 
 Some of the methods trigger the same events. This is due to cross-calling of
 shared subroutines. However, any one event should be triggered no more than
@@ -44,7 +42,7 @@ use App::Info::Util;
 use App::Info::Lib;
 use vars qw(@ISA $VERSION);
 @ISA = qw(App::Info::Lib);
-$VERSION = '0.49';
+$VERSION = '0.57';
 use constant WIN32 => $^O eq 'MSWin32';
 
 my $u = App::Info::Util->new;
@@ -888,14 +886,19 @@ that ought to be searched for libraries and includes.
 
 Improve this class by borrowing code from Matt Seargent's AxKit F<Makefil.PL>.
 
-=head1 BUGS
+=head1 SUPPORT
 
-Please send bug reports to <bug-app-info@rt.cpan.org> or file them at
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=App-Info>.
+This module is stored in an open L<GitHub
+repository|http://github.com/theory/app-info/>. Feel free to fork and
+contribute!
+
+Please file bug reports via L<GitHub
+Issues|http://github.com/theory/app-info/issues/> or by sending mail to
+L<bug-App-Info@rt.cpan.org|mailto:bug-App-Info@rt.cpan.org>.
 
 =head1 AUTHOR
 
-David Wheeler <david@justatheory.com> based on code by Sam Tregar
+David E. Wheeler <david@justatheory.com> based on code by Sam Tregar
 <sam@tregar.com>.
 
 =head1 SEE ALSO
@@ -906,7 +909,7 @@ L<Text::Iconv|Text::Iconv>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2004, David Wheeler. All Rights Reserved.
+Copyright (c) 2002-2011, David E. Wheeler. Some Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under the
 same terms as Perl itself.
