@@ -1,7 +1,5 @@
 package App::Info::RDBMS::SQLite;
 
-# $Id: SQLite.pm 2577 2006-02-05 03:11:10Z theory $
-
 =head1 NAME
 
 App::Info::RDBMS::SQLite - Information about SQLite
@@ -27,7 +25,7 @@ installed on the local system. It implements all of the methods defined by
 App::Info::RDBMS. Methods that trigger events will trigger them only the first
 time they're called (See L<App::Info|App::Info> for documentation on handling
 events). To start over (after, say, someone has installed SQLite) construct a
-new App::Info::RDBMS::SQLite object to aggregate new metadata.
+new App::Info::RDBMS::SQLite object to aggregate new meta data.
 
 Some of the methods trigger the same events. This is due to cross-calling of
 shared subroutines. However, any one event should be triggered no more than
@@ -43,10 +41,9 @@ triggered once, by whichever of those four methods is called first.
 use strict;
 use App::Info::RDBMS;
 use App::Info::Util;
-use Config;
 use vars qw(@ISA $VERSION);
 @ISA = qw(App::Info::RDBMS);
-$VERSION = '0.49';
+$VERSION = '0.57';
 use constant WIN32 => $^O eq 'MSWin32';
 
 my $u = App::Info::Util->new;
@@ -213,7 +210,7 @@ my $get_version = sub {
         $self->info('Grabbing version from DBD::SQLite');
         $version = $self->{dbh}->{sqlite_version};
         unless ($version) {
-            $self->error("Failed to retreive SQLite version from DBD::SQLite");
+            $self->error("Failed to retrieve SQLite version from DBD::SQLite");
             return;
         }
 
@@ -245,7 +242,7 @@ my $get_version = sub {
   my $version = $sqlite->version;
 
 Returns the SQLite version number. App::Info::RDBMS::SQLite parses the version
-number from the system call C<`sqlite -version`> or retreives it from
+number from the system call C<`sqlite -version`> or retrieves it from
 DBD::SQLite.
 
 B<Events:>
@@ -260,7 +257,7 @@ Executing `sqlite -version`
 
 Failed to find SQLite version with `sqlite -version`
 
-Failed to retreive SQLite version from DBD::SQLite
+Failed to retrieve SQLite version from DBD::SQLite
 
 Unable to parse name from string
 
@@ -309,7 +306,7 @@ sub version {
   my $major_version = $sqlite->major_version;
 
 Returns the SQLite major version number. App::Info::RDBMS::SQLite parses the
-version number from the system call C<`sqlite -version`> or retreives it from
+version number from the system call C<`sqlite -version`> or retrieves it from
 DBD::SQLite. For example, if C<version()> returns "3.0.8", then this method
 returns "3".
 
@@ -325,7 +322,7 @@ Executing `sqlite -version`
 
 Failed to find SQLite version with `sqlite -version`
 
-Failed to retreive SQLite version from DBD::SQLite
+Failed to retrieve SQLite version from DBD::SQLite
 
 Unable to parse name from string
 
@@ -364,7 +361,7 @@ sub major_version {
   my $minor_version = $sqlite->minor_version;
 
 Returns the SQLite minor version number. App::Info::RDBMS::SQLite parses the
-version number from the system call C<`sqlite -version`> or retreives it from
+version number from the system call C<`sqlite -version`> or retrieves it from
 DBD::SQLite. For example, if C<version()> returns "3.0.8", then this method
 returns "0".
 
@@ -380,7 +377,7 @@ Executing `sqlite -version`
 
 Failed to find SQLite version with `sqlite -version`
 
-Failed to retreive SQLite version from DBD::SQLite
+Failed to retrieve SQLite version from DBD::SQLite
 
 Unable to parse name from string
 
@@ -415,7 +412,7 @@ sub minor_version {
   my $patch_version = $sqlite->patch_version;
 
 Returns the SQLite patch version number. App::Info::RDBMS::SQLite parses the
-version number from the system call C<`sqlite -version`> or retreives it from
+version number from the system call C<`sqlite -version`> or retrieves it from
 DBD::SQLite. For example, if C<version()> returns "3.0.8", then this method
 returns "8".
 
@@ -431,7 +428,7 @@ Executing `sqlite -version`
 
 Failed to find SQLite version with `sqlite -version`
 
-Failed to retreive SQLite version from DBD::SQLite
+Failed to retrieve SQLite version from DBD::SQLite
 
 Unable to parse name from string
 
@@ -465,7 +462,7 @@ sub patch_version {
 
   my $executable = $sqlite->executable;
 
-Returns the path to the Sqlite executable, usually F<sqlite3> or F<sqlite>,
+Returns the path to the SQLite executable, usually F<sqlite3> or F<sqlite>,
 which will be defined by one of the names returned byC<search_exe_names()>.
 The executable is searched for in C<new()>, so there are no events for this
 method.
@@ -481,7 +478,7 @@ sub executable { shift->{executable} }
   my $bin_dir = $sqlite->bin_dir;
 
 Returns the SQLite binary directory path. App::Info::RDBMS::SQLite simply
-retreives it as the directory part of the path to the SQLite executable.
+retrieves it as the directory part of the path to the SQLite executable.
 
 =cut
 
@@ -519,7 +516,7 @@ Searching for shared object library directory
 
 =item error
 
-Cannot find shared object library direcory
+Cannot find shared object library directory
 
 =item unknown
 
@@ -535,7 +532,7 @@ my $lib_dir = sub {
     $self->info("Searching for $label directory");
     my $dir;
     unless ($dir = $u->first_cat_dir(\@_, $self->search_lib_dirs)) {
-        $self->error("Cannot find $label direcory");
+        $self->error("Cannot find $label directory");
         $dir = $self->unknown(
             key      => "sqlite $key dir",
             callback => sub { $u->first_cat_dir(\@_, $_) },
@@ -576,7 +573,7 @@ Searching for shared object library directory
 
 =item error
 
-Cannot find shared object library direcory
+Cannot find shared object library directory
 
 =item unknown
 
@@ -873,14 +870,19 @@ sub search_inc_dirs {
 1;
 __END__
 
-=head1 BUGS
+=head1 SUPPORT
 
-Please send bug reports to <bug-app-info@rt.cpan.org> or file them at
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=App-Info>.
+This module is stored in an open L<GitHub
+repository|http://github.com/theory/app-info/>. Feel free to fork and
+contribute!
+
+Please file bug reports via L<GitHub
+Issues|http://github.com/theory/app-info/issues/> or by sending mail to
+L<bug-App-Info@rt.cpan.org|mailto:bug-App-Info@rt.cpan.org>.
 
 =head1 AUTHOR
 
-David Wheeler <david@justatheory.com>
+David E. Wheeler <david@justatheory.com>
 
 =head1 SEE ALSO
 
@@ -896,7 +898,7 @@ L<http://www.sqlite.org/> is the SQLite home page.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2004, David Wheeler. All Rights Reserved.
+Copyright (c) 2004-2011, David E. Wheeler. Some Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under the
 same terms as Perl itself.
